Data

Struct Data 

pub struct Data {
    pub version: usize,
    pub ecc_level: EccLevel,
    pub mask: i32,
    pub data_type: Option<DataType>,
    pub payload: Vec<u8>,
    pub eci: Option<Eci>,
}
This structure holds the decoded QR-code data

Fields

version: usize

Various parameters of the QR-code. These can mostly be ignored if you only care about the data.

ecc_level: EccLevelmask: i32data_type: Option<DataType>

This field is the highest-valued data type found in the QR code.

payload: Vec<u8>

Data payload. For the Kanji datatype, payload is encoded as Shift-JIS. For all other datatypes, payload is ASCII text.

eci: Option<Eci>

ECI assignment number